@@ -35,8 +35,10 @@ module Crypto.Saltine.Internal.ByteSizes (
   multScalar,
   secretBoxKey,
   secretBoxNonce,
+  secretBoxMac,
   secretBoxZero,
   secretBoxBoxZero,
+  aead_xchacha20poly1305_ietf_ABYTES,
   sign,
   signPK,
   signSK,
@@ -56,7 +58,7 @@ boxPK, boxSK, boxNonce, boxZero, boxBoxZero :: Int
 boxMac, boxBeforeNM, sealedBox :: Int
 onetime, onetimeKey :: Int
 mult, multScalar :: Int
-secretBoxKey, secretBoxNonce, secretBoxZero, secretBoxBoxZero :: Int
+secretBoxKey, secretBoxNonce, secretBoxMac, secretBoxZero, secretBoxBoxZero :: Int
 sign, signPK, signSK :: Int
 streamKey, streamNonce :: Int
 hash, shorthash, shorthashKey :: Int
@@ -109,6 +111,8 @@ multScalar = fromIntegral c_crypto_scalarmult_scalarbytes
 secretBoxKey     = fromIntegral c_crypto_secretbox_keybytes
 -- | Size of a @crypto_secretbox@ nonce
 secretBoxNonce   = fromIntegral c_crypto_secretbox_noncebytes
+-- | Size of a @crypto_secretbox@ mac
+secretBoxMac     = fromIntegral c_crypto_secretbox_macbytes
 -- | Size of 0-padding prepended to messages before using
 -- @crypto_secretbox@ or after using @crypto_secretbox_open@
 secretBoxZero    = fromIntegral c_crypto_secretbox_zerobytes
@@ -116,6 +120,9 @@ secretBoxZero    = fromIntegral c_crypto_secretbox_zerobytes
 -- @crypto_secretbox_open@ or after using @crypto_secretbox@
 secretBoxBoxZero = fromIntegral c_crypto_secretbox_boxzerobytes
 
+aead_xchacha20poly1305_ietf_ABYTES :: Int
+aead_xchacha20poly1305_ietf_ABYTES = fromIntegral c_crypto_aead_xchacha20poly1305_ietf_ABYTES 
+
 -- Signatures
 -- | The maximum size of a signature prepended to a message to form a
 -- signed message.
@@ -185,6 +192,8 @@ foreign import ccall "crypto_secretbox_keybytes"
   c_crypto_secretbox_keybytes :: CSize
 foreign import ccall "crypto_secretbox_noncebytes"
   c_crypto_secretbox_noncebytes :: CSize
+foreign import ccall "crypto_secretbox_macbytes"
+  c_crypto_secretbox_macbytes :: CSize
 foreign import ccall "crypto_secretbox_zerobytes"
   c_crypto_secretbox_zerobytes :: CSize
 foreign import ccall "crypto_secretbox_boxzerobytes"
@@ -201,6 +210,13 @@ foreign import ccall "crypto_sign_secretkeybytes"
 -- HARDCODED
 -- ---------
 
+-- | The size of a @crypto_aead_tag@.
+--
+-- HARDCODED to be @crypto_aead_xchacha20poly1305_ietf_ABYTES@ for now until Sodium
+-- exports the C constant (is a macro).
+c_crypto_aead_xchacha20poly1305_ietf_ABYTES :: CSize
+c_crypto_aead_xchacha20poly1305_ietf_ABYTES = 16
+
 -- | The size of a @crypto_stream@ or @crypto_stream_xor@
 -- key. HARDCODED to be @crypto_stream_xsalsa20@ for now until Sodium
 -- exports the C constant.
